@@ -52,6 +52,7 @@ def _create_config(
         auth_config=auth_config,
         auth_token=_AuthToken.create_non_expiring(token),
         url=URL("https://dev.neu.ro/api/v1"),
+        admin_url=URL("https://dev.neu.ro/apis/admin/v1"),
         version=__version__,
         cluster_name=cluster_config.name,
         clusters={cluster_config.name: cluster_config},
@@ -79,11 +80,12 @@ async def mock_for_login(
             "auth_url": str(srv.make_url("/authorize")),
             "token_url": str(srv.make_url("/oauth/token")),
             "logout_url": str(srv.make_url("/v2/logout")),
+            "admin_url": str(srv.make_url("/apis/admin/v1")),
             "client_id": "banana",
             "audience": "https://test.dev.neu.ro",
             "headless_callback_url": str(srv.make_url("/oauth/show-code")),
             "callback_urls": callback_urls,
-            "success_redirect_url": "https://neu.ro/#test",
+            "success_redirect_url": "http://example.com",
         }
 
         if (
